import CoreBluetooth
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBAdvertisementData(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertIsInstance(CoreBluetooth.CBAdvertisementDataLocalNameKey, str)
        self.assertIsInstance(CoreBluetooth.CBAdvertisementDataTxPowerLevelKey, str)
        self.assertIsInstance(CoreBluetooth.CBAdvertisementDataServiceUUIDsKey, str)
        self.assertIsInstance(CoreBluetooth.CBAdvertisementDataServiceDataKey, str)
        self.assertIsInstance(CoreBluetooth.CBAdvertisementDataManufacturerDataKey, str)
        self.assertIsInstance(
            CoreBluetooth.CBAdvertisementDataOverflowServiceUUIDsKey, str
        )
        self.assertIsInstance(CoreBluetooth.CBAdvertisementDataIsConnectable, str)
        self.assertIsInstance(
            CoreBluetooth.CBAdvertisementDataSolicitedServiceUUIDsKey, str
        )



import CoreBluetooth
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBAdvertisementData(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertIsInstance(
            CoreBluetooth.CBPeripheralManagerOptionShowPowerAlertKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBPeripheralManagerOptionRestoreIdentifierKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBPeripheralManagerRestoredStateServicesKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBPeripheralManagerRestoredStateServicesKey, str
        )



import CoreBluetooth
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBPeripheral(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(CoreBluetooth.CBCharacteristicWriteType)
        self.assertIsEnumType(CoreBluetooth.CBPeripheralState)

    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(CoreBluetooth.CBPeripheralStateDisconnected, 0)
        self.assertEqual(CoreBluetooth.CBPeripheralStateConnecting, 1)
        self.assertEqual(CoreBluetooth.CBPeripheralStateConnected, 2)
        self.assertEqual(CoreBluetooth.CBPeripheralStateDisconnecting, 3)

        self.assertEqual(CoreBluetooth.CBCharacteristicWriteWithResponse, 0)
        self.assertEqual(CoreBluetooth.CBCharacteristicWriteWithoutResponse, 1)

    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(CoreBluetooth.CBPeripheral, objc.objc_class)

    @min_os_level("10.9")
    def testMethods(self):
        self.assertArgIsBOOL(
            CoreBluetooth.CBPeripheral.setNotifyValue_forCharacteristic_, 0
        )

    @min_os_level("10.9")
    def testMethods2(self):
        self.assertResultIsBOOL(CoreBluetooth.CBPeripheral.isConnected)

    @min_os_level("10.13")
    def testMethods10_13(self):
        self.assertResultIsBOOL(CoreBluetooth.CBPeripheral.canSendWriteWithoutResponse)

    @min_os_level("10.9")
    def testProtocols(self):
        self.assertIsInstance(
            objc.protocolNamed("CBPeripheralDelegate"), objc.formal_protocol
        )



import CoreBluetooth
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBService(TestCase):
    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(CoreBluetooth.CBService, objc.objc_class)
        self.assertIsInstance(CoreBluetooth.CBMutableService, objc.objc_class)

    @min_os_level("10.9")
    def testMethods(self):
        self.assertResultIsBOOL(CoreBluetooth.CBService.isPrimary)
        self.assertResultIsBOOL(CoreBluetooth.CBMutableService.isPrimary)
        self.assertArgIsBOOL(CoreBluetooth.CBMutableService.initWithType_primary_, 1)



# This file is generated by objective.metadata
#
# Last update: Mon Feb 21 22:24:16 2022
#
# flake8: noqa

import objc, sys
from typing import NewType

if sys.maxsize > 2**32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$CBATTErrorDomain$CBAdvertisementDataIsConnectable$CBAdvertisementDataLocalNameKey$CBAdvertisementDataManufacturerDataKey$CBAdvertisementDataOverflowServiceUUIDsKey$CBAdvertisementDataServiceDataKey$CBAdvertisementDataServiceUUIDsKey$CBAdvertisementDataSolicitedServiceUUIDsKey$CBAdvertisementDataTxPowerLevelKey$CBCentralManagerOptionRestoreIdentifierKey$CBCentralManagerOptionShowPowerAlertKey$CBCentralManagerRestoredStatePeripheralsKey$CBCentralManagerRestoredStateScanOptionsKey$CBCentralManagerRestoredStateScanServicesKey$CBCentralManagerScanOptionAllowDuplicatesKey$CBCentralManagerScanOptionSolicitedServiceUUIDsKey$CBConnectPeripheralOptionEnableTransportBridgingKey$CBConnectPeripheralOptionNotifyOnConnectionKey$CBConnectPeripheralOptionNotifyOnDisconnectionKey$CBConnectPeripheralOptionNotifyOnNotificationKey$CBConnectPeripheralOptionRequiresANCS$CBConnectPeripheralOptionStartDelayKey$CBConnectionEventMatchingOptionPeripheralUUIDs$CBConnectionEventMatchingOptionServiceUUIDs$CBErrorDomain$CBPeripheralManagerOptionRestoreIdentifierKey$CBPeripheralManagerOptionShowPowerAlertKey$CBPeripheralManagerRestoredStateAdvertisementDataKey$CBPeripheralManagerRestoredStateServicesKey$CBUUIDAppearanceString$CBUUIDCharacteristicAggregateFormatString$CBUUIDCharacteristicExtendedPropertiesString$CBUUIDCharacteristicFormatString$CBUUIDCharacteristicUserDescriptionString$CBUUIDCharacteristicValidRangeString$CBUUIDClientCharacteristicConfigurationString$CBUUIDDeviceNameString$CBUUIDGenericAccessProfileString$CBUUIDGenericAttributeProfileString$CBUUIDL2CAPPSMCharacteristicString$CBUUIDPeripheralPreferredConnectionParametersString$CBUUIDPeripheralPrivacyFlagString$CBUUIDReconnectionAddressString$CBUUIDServerCharacteristicConfigurationString$CBUUIDServiceChangedString$"""
enums = """$CBATTErrorAttributeNotFound@10$CBATTErrorAttributeNotLong@11$CBATTErrorInsufficientAuthentication@5$CBATTErrorInsufficientAuthorization@8$CBATTErrorInsufficientEncryption@15$CBATTErrorInsufficientEncryptionKeySize@12$CBATTErrorInsufficientResources@17$CBATTErrorInvalidAttributeValueLength@13$CBATTErrorInvalidHandle@1$CBATTErrorInvalidOffset@7$CBATTErrorInvalidPdu@4$CBATTErrorPrepareQueueFull@9$CBATTErrorReadNotPermitted@2$CBATTErrorRequestNotSupported@6$CBATTErrorSuccess@0$CBATTErrorUnlikelyError@14$CBATTErrorUnsupportedGroupType@16$CBATTErrorWriteNotPermitted@3$CBAttributePermissionsReadEncryptionRequired@4$CBAttributePermissionsReadable@1$CBAttributePermissionsWriteEncryptionRequired@8$CBAttributePermissionsWriteable@2$CBCentralManagerFeatureExtendedScanAndConnect@1$CBCentralManagerStatePoweredOff@4$CBCentralManagerStatePoweredOn@5$CBCentralManagerStateResetting@1$CBCentralManagerStateUnauthorized@3$CBCentralManagerStateUnknown@0$CBCentralManagerStateUnsupported@2$CBCharacteristicPropertyAuthenticatedSignedWrites@64$CBCharacteristicPropertyBroadcast@1$CBCharacteristicPropertyExtendedProperties@128$CBCharacteristicPropertyIndicate@32$CBCharacteristicPropertyIndicateEncryptionRequired@512$CBCharacteristicPropertyNotify@16$CBCharacteristicPropertyNotifyEncryptionRequired@256$CBCharacteristicPropertyRead@2$CBCharacteristicPropertyWrite@8$CBCharacteristicPropertyWriteWithoutResponse@4$CBCharacteristicWriteWithResponse@0$CBCharacteristicWriteWithoutResponse@1$CBConnectionEventPeerConnected@1$CBConnectionEventPeerDisconnected@0$CBErrorAlreadyAdvertising@9$CBErrorConnectionFailed@10$CBErrorConnectionLimitReached@11$CBErrorConnectionTimeout@6$CBErrorEncryptionTimedOut@15$CBErrorInvalidHandle@2$CBErrorInvalidParameters@1$CBErrorNotConnected@3$CBErrorOperationCancelled@5$CBErrorOperationNotSupported@13$CBErrorOutOfSpace@4$CBErrorPeerRemovedPairingInformation@14$CBErrorPeripheralDisconnected@7$CBErrorTooManyLEPairedDevices@16$CBErrorUUIDNotAllowed@8$CBErrorUnknown@0$CBErrorUnknownDevice@12$CBErrorUnkownDevice@12$CBManagerAuthorizationAllowedAlways@3$CBManagerAuthorizationDenied@2$CBManagerAuthorizationNotDetermined@0$CBManagerAuthorizationRestricted@1$CBManagerStatePoweredOff@4$CBManagerStatePoweredOn@5$CBManagerStateResetting@1$CBManagerStateUnauthorized@3$CBManagerStateUnknown@0$CBManagerStateUnsupported@2$CBPeripheralAuthorizationStatusAuthorized@3$CBPeripheralAuthorizationStatusDenied@2$CBPeripheralAuthorizationStatusNotDetermined@0$CBPeripheralAuthorizationStatusRestricted@1$CBPeripheralManagerAuthorizationStatusAuthorized@3$CBPeripheralManagerAuthorizationStatusDenied@2$CBPeripheralManagerAuthorizationStatusNotDetermined@0$CBPeripheralManagerAuthorizationStatusRestricted@1$CBPeripheralManagerConnectionLatencyHigh@2$CBPeripheralManagerConnectionLatencyLow@0$CBPeripheralManagerConnectionLatencyMedium@1$CBPeripheralManagerStatePoweredOff@4$CBPeripheralManagerStatePoweredOn@5$CBPeripheralManagerStateResetting@1$CBPeripheralManagerStateUnauthorized@3$CBPeripheralManagerStateUnknown@0$CBPeripheralManagerStateUnsupported@2$CBPeripheralStateConnected@2$CBPeripheralStateConnecting@1$CBPeripheralStateDisconnected@0$CBPeripheralStateDisconnecting@3$"""
misc.update(
    {
        "CBCentralManagerFeature": NewType("CBCentralManagerFeature", int),
        "CBError": NewType("CBError", int),
        "CBPeripheralManagerState": NewType("CBPeripheralManagerState", int),
        "CBManagerAuthorization": NewType("CBManagerAuthorization", int),
        "CBConnectionEvent": NewType("CBConnectionEvent", int),
        "CBCharacteristicProperties": NewType("CBCharacteristicProperties", int),
        "CBATTError": NewType("CBATTError", int),
        "CBPeripheralState": NewType("CBPeripheralState", int),
        "CBCharacteristicWriteType": NewType("CBCharacteristicWriteType", int),
        "CBPeripheralManagerConnectionLatency": NewType(
            "CBPeripheralManagerConnectionLatency", int
        ),
        "CBManagerState": NewType("CBManagerState", int),
        "CBAttributePermissions": NewType("CBAttributePermissions", int),
        "CBPeripheralManagerAuthorizationStatus": NewType(
            "CBPeripheralManagerAuthorizationStatus", int
        ),
        "CBCentralManagerState": NewType("CBCentralManagerState", int),
    }
)
misc.update(
    {"CBConnectionEventMatchingOption": NewType("CBConnectionEventMatchingOption", str)}
)
misc.update({})
aliases = {
    "CBCentralManagerStateUnknown": "CBManagerStateUnknown",
    "CBPeripheralManagerStatePoweredOff": "CBManagerStatePoweredOff",
    "CBCentralManagerStatePoweredOn": "CBManagerStatePoweredOn",
    "CBCentralManagerStatePoweredOff": "CBManagerStatePoweredOff",
    "CBPeripheralManagerStateUnauthorized": "CBManagerStateUnauthorized",
    "CBPeripheralManagerStatePoweredOn": "CBManagerStatePoweredOn",
    "CBCentralManagerStateUnsupported": "CBManagerStateUnsupported",
    "CBCentralManagerStateUnauthorized": "CBManagerStateUnauthorized",
    "CBPeripheralManagerStateUnknown": "CBManagerStateUnknown",
    "CBPeripheralManagerStateResetting": "CBManagerStateResetting",
    "CBPeripheralManagerStateUnsupported": "CBManagerStateUnsupported",
    "CBCentralManagerStateResetting": "CBManagerStateResetting",
}
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(b"CBCentralManager", b"isScanning", {"retval": {"type": "Z"}})
    r(b"CBCentralManager", b"supportsFeatures:", {"retval": {"type": b"Z"}})
    r(b"CBCharacteristic", b"isBroadcasted", {"retval": {"type": b"Z"}})
    r(b"CBCharacteristic", b"isNotifying", {"retval": {"type": b"Z"}})
    r(b"CBMutableService", b"initWithType:primary:", {"arguments": {3: {"type": b"Z"}}})
    r(b"CBMutableService", b"isPrimary", {"retval": {"type": b"Z"}})
    r(b"CBMutableService", b"setIsPrimary:", {"arguments": {2: {"type": b"Z"}}})
    r(b"CBPeripheral", b"ancsAuthorized", {"retval": {"type": b"Z"}})
    r(b"CBPeripheral", b"canSendWriteWithoutResponse", {"retval": {"type": "Z"}})
    r(b"CBPeripheral", b"isConnected", {"retval": {"type": b"Z"}})
    r(
        b"CBPeripheral",
        b"setNotifyValue:forCharacteristic:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(b"CBPeripheralManager", b"isAdvertising", {"retval": {"type": b"Z"}})
    r(
        b"CBPeripheralManager",
        b"publishL2CAPChannelWithEncryption:",
        {"arguments": {2: {"type": "Z"}}},
    )
    r(
        b"CBPeripheralManager",
        b"updateValue:forCharacteristic:onSubscribedCentrals:",
        {"retval": {"type": b"Z"}},
    )
    r(b"CBService", b"isPrimary", {"retval": {"type": b"Z"}})
    r(
        b"NSObject",
        b"centralManager:connectionEventDidOccur:forPeripheral:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"q"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"centralManager:didConnectPeripheral:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"centralManager:didDisconnectPeripheral:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"centralManager:didDiscoverPeripheral:advertisementData:RSSI:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {"type": b"@"},
            },
        },
    )
    r(
        b"NSObject",
        b"centralManager:didFailToConnectPeripheral:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"centralManager:didRetrieveConnectedPeripherals:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"centralManager:didRetrievePeripherals:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"centralManager:didUpdateANCSAuthorizationForPeripheral:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"centralManager:willRestoreState:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"centralManagerDidUpdateState:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"peripheral:didDiscoverCharacteristicsForService:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didDiscoverDescriptorsForCharacteristic:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didDiscoverIncludedServicesForService:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didDiscoverServices:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didModifyServices:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didOpenL2CAPChannel:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didReadRSSI:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didUpdateNotificationStateForCharacteristic:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didUpdateValueForCharacteristic:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didUpdateValueForDescriptor:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didWriteValueForCharacteristic:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheral:didWriteValueForDescriptor:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralDidInvalidateServices:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"peripheralDidUpdateName:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"peripheralDidUpdateRSSI:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralIsReadyToSendWriteWithoutResponse:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"peripheralManager:central:didSubscribeToCharacteristic:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManager:central:didUnsubscribeFromCharacteristic:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManager:didAddService:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManager:didOpenL2CAPChannel:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "S"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManager:didPublishL2CAPChannel:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "S"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManager:didReceiveReadRequest:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManager:didReceiveWriteRequests:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManager:didUnpublishL2CAPChannel:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": "S"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManager:willRestoreState:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManagerDidStartAdvertising:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"peripheralManagerDidUpdateState:",
        {"required": True, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"peripheralManagerIsReadyToUpdateSubscribers:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import CoreBluetooth
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBCentral(TestCase):
    def test_typed_enum(self):
        self.assertIsTypedEnum(CoreBluetooth.CBConnectionEventMatchingOption, str)

    @min_os_level("10.9")
    def testConstants(self):
        self.assertIsInstance(
            CoreBluetooth.CBCentralManagerOptionShowPowerAlertKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBCentralManagerScanOptionAllowDuplicatesKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBCentralManagerScanOptionSolicitedServiceUUIDsKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBConnectPeripheralOptionNotifyOnDisconnectionKey, str
        )

    @min_os_level("10.13")
    def testConstants10_13(self):
        self.assertIsInstance(
            CoreBluetooth.CBCentralManagerOptionRestoreIdentifierKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBConnectPeripheralOptionNotifyOnConnectionKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBConnectPeripheralOptionNotifyOnNotificationKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBCentralManagerRestoredStatePeripheralsKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBCentralManagerRestoredStateScanServicesKey, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBCentralManagerRestoredStateScanOptionsKey, str
        )

    # @min_os_level("11.0")
    # def testConstants11_0(self):
    # XXX: unavailable according to macOS 12 SDK.
    # self.assertIsInstance(
    #   CoreBluetooth.CBConnectionEventMatchingOptionServiceUUIDs, str
    # )
    # self.assertIsInstance(
    #    CoreBluetooth.CBConnectionEventMatchingOptionPeripheralUUIDs, str
    # )
    # pass

    @min_os_level("10.14")
    def testConstants10_14(self):
        # XXX: This is currently documented as a 10.13 constant, but isn't available there
        self.assertIsInstance(CoreBluetooth.CBConnectPeripheralOptionStartDelayKey, str)



import CoreBluetooth
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBAdvertisementData(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(CoreBluetooth.CBATTError)
        self.assertIsEnumType(CoreBluetooth.CBError)

    @min_os_level("10.9")
    def testConstants(self):
        self.assertIsInstance(CoreBluetooth.CBErrorDomain, str)
        self.assertIsInstance(CoreBluetooth.CBATTErrorDomain, str)

        self.assertEqual(CoreBluetooth.CBErrorUnknown, 0)
        self.assertEqual(CoreBluetooth.CBErrorInvalidParameters, 1)
        self.assertEqual(CoreBluetooth.CBErrorInvalidHandle, 2)
        self.assertEqual(CoreBluetooth.CBErrorNotConnected, 3)
        self.assertEqual(CoreBluetooth.CBErrorOutOfSpace, 4)
        self.assertEqual(CoreBluetooth.CBErrorOperationCancelled, 5)
        self.assertEqual(CoreBluetooth.CBErrorConnectionTimeout, 6)
        self.assertEqual(CoreBluetooth.CBErrorPeripheralDisconnected, 7)
        self.assertEqual(CoreBluetooth.CBErrorUUIDNotAllowed, 8)
        self.assertEqual(CoreBluetooth.CBErrorAlreadyAdvertising, 9)
        self.assertEqual(CoreBluetooth.CBErrorConnectionFailed, 10)
        self.assertEqual(CoreBluetooth.CBErrorConnectionLimitReached, 11)
        self.assertEqual(CoreBluetooth.CBErrorUnkownDevice, 12)
        self.assertEqual(CoreBluetooth.CBErrorUnknownDevice, 12)
        self.assertEqual(CoreBluetooth.CBErrorOperationNotSupported, 13)
        self.assertEqual(CoreBluetooth.CBErrorPeerRemovedPairingInformation, 14)
        self.assertEqual(CoreBluetooth.CBErrorEncryptionTimedOut, 15)
        self.assertEqual(CoreBluetooth.CBErrorTooManyLEPairedDevices, 16)

        self.assertEqual(CoreBluetooth.CBATTErrorSuccess, 0x00)
        self.assertEqual(CoreBluetooth.CBATTErrorInvalidHandle, 0x01)
        self.assertEqual(CoreBluetooth.CBATTErrorReadNotPermitted, 0x02)
        self.assertEqual(CoreBluetooth.CBATTErrorWriteNotPermitted, 0x03)
        self.assertEqual(CoreBluetooth.CBATTErrorInvalidPdu, 0x04)
        self.assertEqual(CoreBluetooth.CBATTErrorInsufficientAuthentication, 0x05)
        self.assertEqual(CoreBluetooth.CBATTErrorRequestNotSupported, 0x06)
        self.assertEqual(CoreBluetooth.CBATTErrorInvalidOffset, 0x07)
        self.assertEqual(CoreBluetooth.CBATTErrorInsufficientAuthorization, 0x08)
        self.assertEqual(CoreBluetooth.CBATTErrorPrepareQueueFull, 0x09)
        self.assertEqual(CoreBluetooth.CBATTErrorAttributeNotFound, 0x0A)
        self.assertEqual(CoreBluetooth.CBATTErrorAttributeNotLong, 0x0B)
        self.assertEqual(CoreBluetooth.CBATTErrorInsufficientEncryptionKeySize, 0x0C)
        self.assertEqual(CoreBluetooth.CBATTErrorInvalidAttributeValueLength, 0x0D)
        self.assertEqual(CoreBluetooth.CBATTErrorUnlikelyError, 0x0E)
        self.assertEqual(CoreBluetooth.CBATTErrorInsufficientEncryption, 0x0F)
        self.assertEqual(CoreBluetooth.CBATTErrorUnsupportedGroupType, 0x10)
        self.assertEqual(CoreBluetooth.CBATTErrorInsufficientResources, 0x11)



import CoreBluetooth
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBUUID(TestCase):
    @min_os_level("10.9")
    def testConstants(self):
        self.assertIsInstance(
            CoreBluetooth.CBUUIDCharacteristicExtendedPropertiesString, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBUUIDCharacteristicUserDescriptionString, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBUUIDClientCharacteristicConfigurationString, str
        )
        self.assertIsInstance(
            CoreBluetooth.CBUUIDServerCharacteristicConfigurationString, str
        )
        self.assertIsInstance(CoreBluetooth.CBUUIDCharacteristicFormatString, str)
        self.assertIsInstance(
            CoreBluetooth.CBUUIDCharacteristicAggregateFormatString, str
        )
        self.assertIsInstance(CoreBluetooth.CBUUIDGenericAccessProfileString, str)
        self.assertIsInstance(CoreBluetooth.CBUUIDGenericAttributeProfileString, str)
        self.assertIsInstance(CoreBluetooth.CBUUIDDeviceNameString, str)
        self.assertIsInstance(CoreBluetooth.CBUUIDAppearanceString, str)
        self.assertIsInstance(CoreBluetooth.CBUUIDPeripheralPrivacyFlagString, str)
        self.assertIsInstance(CoreBluetooth.CBUUIDReconnectionAddressString, str)
        self.assertIsInstance(
            CoreBluetooth.CBUUIDPeripheralPreferredConnectionParametersString, str
        )
        self.assertIsInstance(CoreBluetooth.CBUUIDServiceChangedString, str)

    @min_os_level("10.13")
    def testConstants10_13(self):
        self.assertIsInstance(CoreBluetooth.CBUUIDCharacteristicValidRangeString, str)
        self.assertIsInstance(CoreBluetooth.CBUUIDL2CAPPSMCharacteristicString, str)

    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(CoreBluetooth.CBUUID, objc.objc_class)



import CoreBluetooth
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestCBAdvertisementData(TestCase):
    def test_enum_types(self):
        self.assertIsEnumType(CoreBluetooth.CBAttributePermissions)
        self.assertIsEnumType(CoreBluetooth.CBCharacteristicProperties)

    @min_os_level("10.9")
    def testClasses(self):
        self.assertIsInstance(CoreBluetooth.CBCharacteristic, objc.objc_class)
        self.assertIsInstance(CoreBluetooth.CBMutableCharacteristic, objc.objc_class)

    @min_os_level("10.9")
    def testConstants(self):
        self.assertEqual(CoreBluetooth.CBCharacteristicPropertyBroadcast, 0x01)
        self.assertEqual(CoreBluetooth.CBCharacteristicPropertyRead, 0x02)
        self.assertEqual(
            CoreBluetooth.CBCharacteristicPropertyWriteWithoutResponse, 0x04
        )
        self.assertEqual(CoreBluetooth.CBCharacteristicPropertyWrite, 0x08)
        self.assertEqual(CoreBluetooth.CBCharacteristicPropertyNotify, 0x10)
        self.assertEqual(CoreBluetooth.CBCharacteristicPropertyIndicate, 0x20)
        self.assertEqual(
            CoreBluetooth.CBCharacteristicPropertyAuthenticatedSignedWrites, 0x40
        )
        self.assertEqual(CoreBluetooth.CBCharacteristicPropertyExtendedProperties, 0x80)
        self.assertEqual(
            CoreBluetooth.CBCharacteristicPropertyNotifyEncryptionRequired, 0x100
        )
        self.assertEqual(
            CoreBluetooth.CBCharacteristicPropertyIndicateEncryptionRequired, 0x200
        )

        self.assertEqual(CoreBluetooth.CBAttributePermissionsReadable, 0x01)
        self.assertEqual(CoreBluetooth.CBAttributePermissionsWriteable, 0x02)
        self.assertEqual(
            CoreBluetooth.CBAttributePermissionsReadEncryptionRequired, 0x04
        )
        self.assertEqual(
            CoreBluetooth.CBAttributePermissionsWriteEncryptionRequired, 0x08
        )

    @min_os_level("10.9")
    def testMethods(self):
        self.assertResultIsBOOL(CoreBluetooth.CBCharacteristic.isBroadcasted)
        self.assertResultIsBOOL(CoreBluetooth.CBCharacteristic.isNotifying)
